@@ -397,3 +397,14 @@ class ReverseKey(object):
 
     def __lt__(self, o):
         return o.data < self.data
+
+def unique(iterable):
+    """
+    Исключить из списка дублирующие элементы, не меняя порядка
+    """
+    seen = {}
+    for x in iterable:
+        if x in seen:
+            continue
+        seen[x] = 1
+        yield x
